This dataset was originally shared by Hosmer et al. (2013).
glow11mA data frame with 238 rows and 16 variables:
Matched pair identifier (each case-control pair shares the same value)
Identification Code
Study Site (1–6)
Physician ID code (128 unique codes)
History of prior fracture (1 = Yes, 0 = No)
Years
Kilograms
Centimeters
Body mass index (kg/m\(^2\))
Menopause before age 45 (1 = Yes, 0 = No)
Mother had hip fracture (1 = Yes, 0 = No)
Arms are needed to stand from a chair (1 = Yes, 0 = No)
Former or current smoker (1 = Yes, 0 = No)
Self-reported risk of fracture (1 = Less than others of the same age, 2 = Same as others of the same age, 3 = Greater than others of the same age)
Composite risk score
Any fracture in first year (1 = Yes, 0 = No)